@@ -344,10 +344,15 @@ new messages are incorporated into your folders
 (except during startup) and when you try to change
 folders without committing moves and delete operations."} \
 	{ sound(multifile) soundMultiFile OFF {Play Multiple}
-"If your play command can handle multiple audio files,
-then set this option.  In this case Exmh can run the
-audio program in the background when it needs to
-play multiple sounds."} \
+"Exmh will play the sound more than once if a large 
+number of messages arrive.  If your play command can 
+handle multiple audio files in one invocation, then 
+set this option.  With this option on Exmh will run 
+the play command in the background and the sound 
+filename will be repeated as an argument.
+
+For example, \"play sound sound sound\" would be run 
+in the background if three sounds were to be played."} \
 	[list sound(bell) soundBell OFF {Use terminal bell} \
 "Ring the terminal bell instead of playing an audio file."] \
 	[list sound(cmd) soundCmd $cmd {Play command} \
@@ -357,11 +362,13 @@ name of the audio file is appended to this command line."] \
 	[list sound(newMsg) soundNewMsg drip.au {Sound for a new message} \
 "The name of an audio file to play when
 new messages have arrived.  Relative pathnames are
-searched for in the exmh script library directory."] \
+searched for in the exmh script library directory.
+Pathnames beginning with \"~\" will be expanded."] \
 	[list sound(error) soundError clink.au {Sound for an error} \
 "The name of an audio file to play when
 you forget to commit pending operations.  Relative pathnames are
-searched for in the exmh script library directory."] \
+searched for in the exmh script library directory.
+Pathnames beginning with \"~\" will be expanded."] \
 ]
     if {$sound(enabled) && ([string length $sound(cmd)] == 0)} {
 	set sound(bell) 1
@@ -500,7 +507,8 @@ proc Pgp_Init {} {
     # if there is an appropriate keyring
     foreach v $pgp(supportedversions) {
         if { [file exists [set pgp($v,pubring)]] && 
-             [file isdirectory [set pgp($v,path)]]} {
+             [file isdirectory [set pgp($v,path)]] &&
+	     [file exists $pgp($v,path)/$pgp($v,executable,verify)]} {
             set pgp($v,enabled) 1
             set pgp(enabled) 1
             lappend setup $v
@@ -530,11 +538,10 @@ window so that you will not be prompted with the passphrase prompt." }
 version are currently selected.  Users with multiple PGP keys or PGP
 versions may find it helpful.  Changing this value will require that 
 you exit and re-enter exmh if you've already composed email." }
-    {pgp(sign) pgpSign {CHOICE none standard detached clearsign encryptsign} {Signature options}
+    {pgp(sign) pgpSign {CHOICE none standard clearsign encryptsign} {Signature options}
 "There are multiple ways to sign a message.
     None: Do not sign outgoing messages.
     Standard: Sign outgoing messages.
-    Detached: Use MIME encapsulation for signatures.
     Clearsign: Sign messages so that they can be read by non-PGP mail readers.
     Encryptsign: Sign and encrypt in a single operation.
 This can be changed on the fly from the sedit window." }
@@ -554,8 +561,20 @@ This can be changed on the fly from the sedit window." }
 "There are multiple versions of the PGP program.
     PGP:    Pretty Good Privacy, Version 2
     PGP5:   Pretty Good Privacy, Version 5
+    PGP6:   Pretty Good Privacy, Version 6
     GPG:    GNU Privacy Guard
-This can be changed on the fly from the sedit window." ] ]
+This can be changed on the fly from the sedit window." ] \
+    [list pgp(noversion) pgpNoVersion [concat CHOICE $setup] \
+    {Version of PGP for handling unknown PGP messages} \
+"Very seldom you happen to get PGP messages which don't carry
+the PGP header line
+Version: xxx
+In such a case Exmh falls back to a default PGP version.
+Here you can select, which version to use in these cases.
+    PGP:    Pretty Good Privacy, Version 2
+    PGP5:   Pretty Good Privacy, Version 5
+    PGP6:   Pretty Good Privacy, Version 6
+    GPG:    GNU Privacy Guard." ] ]
 
     Preferences_Add "General PGP Interface" "" {
     {pgp(keeppass) pgpKeepPass ON {Keep PGP passphrase}
@@ -586,6 +605,7 @@ this time period, in minutes, has elapsed." }
 
     # Fix up change in pgp(sign) value
     switch $pgp(sign) {
+	detached -
 	1 {set pgp(sign) standard}
 	0 {set pgp(sign) none}
     }
@@ -632,7 +652,7 @@ proc Glimpse_Init {} {
 	    ExmhLog "$voutput"
 	    return
 	}
-	if {! [regexp {[0-9]\.[0-9]} $voutput glimpse(version)] } {
+	if {! [regexp {[0-9]\.[0-9]*} $voutput glimpse(version)] } {
 	    ExmhLog "glimpse version info error : $voutput"
 	    return
 	}
