@@ -74,7 +74,7 @@ proc MhBackup {} {
     if {[string length $sbackup] == 0} {
 	set sbackup #
     }
-    return sbackup
+    return $sbackup
 }
 
 # Run an MH program and check for errors.
@@ -321,7 +321,22 @@ proc Mh_SetContext { key value } {
     }
 }
 proc Mh_MsgChk {} {
-    catch {MhExec msgchk -nodate -notify mail} result
+    global inc pop
+    
+    if {[string length $inc(pophost)]} {
+	# See if we know the password for this host
+	Pop_GetPassword $inc(pophost)
+	catch {exec msgchk -nodate -notify mail -host $inc(pophost) << $pop(password)} result
+	Exmh_Debug Mh_MsgChk $result
+	# Remove 'Password (host:user):' prompt from result string, and
+	# msgchk returned 1 because no messages were waiting, remove the
+	# error message left by 'exec'
+	regsub {.*\):} $result {} result
+	regsub "\n.*" $result {} result
+    } else {
+	catch {MhExec msgchk -nodate -notify mail} result
+    }
+
     return $result
 }
 proc Mh_MsgCount { spool } {
@@ -657,7 +672,7 @@ proc Mh_Send { msg } {
 	"xterm" {
 	    eval exec $mhProfile(xtermcmd) { \
 		-title "Sending $mhProfile(draft-folder)/$msg ..." \
-		-e sh -c "send -draftf +$mhProfile(draft-folder) -draftm $dst || whatnow -draftf +$mhProfile(draft-folder) -draftm $dst" &}
+		-e sh -c "$mhProfile(sendproc) -draftf +$mhProfile(draft-folder) -draftm $dst || whatnow -draftf +$mhProfile(draft-folder) -draftm $dst" &}
 
 	}
     }
@@ -831,7 +846,7 @@ proc MhSetupNewUser {} {
     Widget_Message .newuser msg -aspect 1000 -text "
 Exmh is a front end to the MH mail handling system.
 Feel free to send comments and bug reports to
-	Brent.Welch@eng.sun.com
+	Brent.Welch@acm.org
 
 It appears you have not used the MH mail system before.
 (Your [file tail $mhProfile(profile)] is missing or incomplete.)
