@@ -1056,16 +1056,17 @@ proc Mime_GetCharset {tkw part} {
     set charset us-ascii
     if [info exists mimeHdr($part,param,charset)] {
 	set charset [string tolower $mimeHdr($part,param,charset)]
-	if {[string length $tkw]} {
 
-	    # Limit the encodings to ones for which we have fonts.
+	# Limit the encodings to ones for which we have fonts.
+
+	if ![info exists mime(registry,$charset)] {
+	    if {[string length $tkw]} {
 
-	    if ![info exists mime(registry,$charset)] {
 		MimeInsertNote $tkw [MimeLabel $part charset] \
 			       "Unknown charset: <$charset>"
 		$tkw insert insert \n
-		set charset us-ascii
 	    }
+	    set charset us-ascii
 	}
     }
     return $charset
@@ -2072,6 +2073,7 @@ proc MimeParseSingle {tkw part fileIO } {
 	set mimeHdr($part,params) {}
     }
     if {![info exists firstLine]} {
+	set firstLinePosition [tell $fileIO]
 	gets $fileIO firstLine
 	if [regexp $miscRE(beginpgp) $firstLine] { set mimeHdr($part,decode) 1 }
     }
@@ -2091,7 +2093,13 @@ proc MimeParseSingle {tkw part fileIO } {
 		set tag [MimeSetCharset $tkw $part]
 		$tkw tag remove noteTag "insert -1line"  end
 		$tkw tag add $tag insert end
+		if [info exists firstLinePosition] {
+		    seek $fileIO $firstLinePosition
+		}
 		Mime_SetFileEncoding $fileIO $part
+		if [info exists firstLinePosition] {
+		    gets $fileIO firstLine
+		}
 	    }  else {
 		set tag {}
 	    }
