@@ -1,6 +1,23 @@
 # pgpGpg.tcl
 
 # $Log: pgpGpg.tcl,v $
+# Revision 1.11  2000/04/18 18:38:33  valdis
+# Fix quote character to use ascii rather than iso8859-ish one
+#
+# Revision 1.10  2000/02/07 13:23:34  gruber
+# fixed run twice function to work with now short keyids
+#
+# Revision 1.9  1999/10/25 15:38:39  kchrist
+# Added a dropKeys pattern to pgpGPG.tcl.
+#
+# Simplified PGP GUI by removing "detached" signature option. Problem
+# was that MIME+standard includes a copy of the message being signed
+# in the signature attachement. What really should be used is
+# MIME+detached. Decided to overload the meaning of "standard". If
+# the format is plain, standard means "binary". If the format is
+# anything else, standard means "detached". Less flexibility but
+# better chances of "doing the right thing".
+#
 # Revision 1.8  1999/09/30 03:51:07  kchrist
 # pgp($v,cmd_Beauty) was getting in the way of pgp($v,cmd_User) for
 # v=gpg so I had to rearrange things a bit.
@@ -67,7 +84,7 @@ Pgp_WWW_Init
 set pgp(pref,HKPkeyserverUrl) { HKPkeyserverUrl HKPKeyServerUrl {keys.pgp.com}
 {Horowitz Key Protocol Server}
 "The hkp (Horowitz Key Protokol) is a subset of the http.
-Its used to tranfer keys to and from a keyserver.
+It's used to tranfer keys to and from a keyserver.
 Give here a hkp server name." }
 
 
@@ -111,7 +128,7 @@ in the Modules Path."] \
 ON "PGP 5.0 Compatibility" \
 "You MUST have enabled this if you want that GnuPG produces
 PGP 5.0 compatible messages.
-Having this enabled, you dont need PGP 5.0 any more." ] ]
+Having this enabled, you don't need PGP 5.0 any more." ] ]
 
     # Before we can build the algorithm choice preferences part
     # we need to examine, which modules are installed on the system
@@ -122,13 +139,10 @@ Having this enabled, you dont need PGP 5.0 any more." ] ]
     Preferences_Add "$label interface" {} [list \
                 [list pgp(gpg,cipheralgo) gpgCipherAlgo \
 [concat CHOICE $pgp(gpg,cipheralgos)] "Default Cipher Algo" \
-"NOTE: If you mark twofish, skipjack or idea as your default
-cipher, please make sure, that you have these
-extension modules installed."] \
+"Your preferred cipher algorithm."] \
                 [list pgp(gpg,digestalgo) gpgDigestAlgo \
 [concat CHOICE $pgp(gpg,digestalgos)] "Default Digest Algo" \
-"NOTE: If you mark tiger as your default digest, please 
-make sure, that the tiger extension module is installed."] \
+"Your preferred digest algorithm."] \
                 [list pgp(gpg,compressalgo) gpgCompressAlgo \
 [concat CHOICE $pgp(gpg,compressalgos)] "Default Compress Algo" \
 "The algorithm, GnuPG uses to compress the text before encrypting.
@@ -312,7 +326,7 @@ set pgp(gpg,args_listPub) {--with-colons --list-keys \"$pattern\"}
 # List seckeys args prototype
 set pgp(gpg,args_listSec) {--with-colons --list-secret-keys \"$pattern\"}
 # Pattern that matches out revoked and nonvalid keys
-set pgp(gpg,pat_dropKeys) {}
+set pgp(gpg,pat_dropKeys) {(^|\n)(pub|sub|sec|ssb|uid):[dren]:[^\n]+}
 # Where to split up the listKeys raw output to form a list
 set pgp(gpg,pat_splitKeys) \n
 # Patterns that match out interesting keys
@@ -374,7 +388,7 @@ set pgp(gpg,pat_checkError) "(BAD_PASSPHRASE\[^\n]+)\n"
 #######################
 # Exec_DetDecryptKeyid
 set pgp(gpg,args_getDecryptKeyid) {--dry-run $in}
-set pgp(gpg,pat_getDecryptKeyid) "NEED_PASSPHRASE (\[^ \n]*)"
+set pgp(gpg,pat_getDecryptKeyid) "NEED_PASSPHRASE ........(........)"
 set pgp(gpg,pat_getDecryptSym) "NEED_PASSPHRASE_SYM"
 
 ###############
