@@ -19,6 +19,23 @@
 # to avoid auto-loading this whole file.
 
 # $Log: pgpMain.tcl,v $
+# Revision 1.20  2000/04/22 10:34:49  gruber
+# Handle PGP messages without Version: xxx
+#
+# Revision 1.19  1999/10/27 14:59:27  kchrist
+# Quick application/pgp bug fix.
+#
+# Revision 1.18  1999/10/25 15:38:39  kchrist
+# Added a dropKeys pattern to pgpGPG.tcl.
+#
+# Simplified PGP GUI by removing "detached" signature option. Problem
+# was that MIME+standard includes a copy of the message being signed
+# in the signature attachement. What really should be used is
+# MIME+detached. Decided to overload the meaning of "standard". If
+# the format is plain, standard means "binary". If the format is
+# anything else, standard means "detached". Less flexibility but
+# better chances of "doing the right thing".
+#
 # Revision 1.17  1999/10/07 14:29:28  kchrist
 # Changed quote file name documentation string to remove ambiguity regarding
 # the location of this file.
@@ -592,7 +609,6 @@ proc Pgp_Process { v srcfile dstfile } {
 	    set typeparams "; x-action=encrypt;"
 	} else {
 	    switch $pgp(sign,$id) {
-		detached -
 		standard {set typeparams "; x-action=signbinary;"}
 		clearsign {set typeparams "; x-action=signclear;"}
 		encryptsign {set typeparams "; x-action=encryptsign;"}
@@ -655,11 +671,7 @@ proc Pgp_Process { v srcfile dstfile } {
     # write the message to be encrypted
     set msgfile [Mime_TempFile "msg"]
     set msg [open $msgfile w 0600]
-    if {$pgp(format,$id) == "plain" && $pgp(sign,$id) == "detached"} {
-	set pgp(sign,$id) "standard"
-    } else {
-	foreach line $pgpheaders { puts $msg [Pgp_Misc_FixHeader $line] }
-    }
+    foreach line $pgpheaders { puts $msg [Pgp_Misc_FixHeader $line] }
     puts $msg ""
     puts -nonewline $msg [read $orig]
     close $orig
@@ -672,10 +684,26 @@ proc Pgp_Process { v srcfile dstfile } {
 	    Pgp_Exec_Encrypt $pgp(version,$id) $msgfile $pgpfile $ids 
 	} else {
 	    switch $pgp(sign,$id) {
-		standard -
-		detached -
-		clearsign {Pgp_Exec_Sign $pgp(version,$id) $msgfile $pgpfile $originator $pgp(sign,$id)}
-		encryptsign {Pgp_Exec_EncryptSign $pgp(version,$id) $msgfile $pgpfile $originator $ids}
+		standard {
+		    # Depending on format standard may mean different
+		    # things. It was decided to keep this ambiguity
+		    # internal instead of exporting it via the GUI.
+		    if {$pgp(format,$id) == "plain"} {
+			Pgp_Exec_Sign $pgp(version,$id) $msgfile $pgpfile \
+				$originator standard
+		    } else {
+			Pgp_Exec_Sign $pgp(version,$id) $msgfile $pgpfile \
+				$originator detached
+		    }
+		}
+		clearsign {
+		    Pgp_Exec_Sign $pgp(version,$id) $msgfile $pgpfile \
+			    $originator clearsign
+		}
+		encryptsign {
+		    Pgp_Exec_EncryptSign $pgp(version,$id) $msgfile $pgpfile \
+			    $originator $ids
+		}
 		none -
 		default {error "<PGP> Message is neither signed, nor encrypted"}
 	    }
@@ -693,7 +721,7 @@ proc Pgp_Process { v srcfile dstfile } {
 	
     switch $pgp(format,$id) {
         app { 
-	    Pgp_ProcessAP $v $dstfile $pgpfile $mailheaders
+	    Pgp_ProcessAP $v $dstfile $pgpfile $mailheaders $typeparams
         }
         pm { 
             Pgp_ProcessPM $v $dstfile $pgpfile $mailheaders $msgfile $id
@@ -706,7 +734,7 @@ proc Pgp_Process { v srcfile dstfile } {
     File_Delete $msgfile $pgpfile
 }
 
-proc Pgp_ProcessAP {v dstfile pgpfile mailheaders} {
+proc Pgp_ProcessAP {v dstfile pgpfile mailheaders typeparams} {
     global pgp
 
     lappend mailheaders \
@@ -813,7 +841,10 @@ proc Pgp_CheckVersion { pgpfile varReal varV } {
         }
     }
     if {![info exists bestversion]} {
-        error "No pattern matches version info in pgp text!"
+        #error "No pattern matches version info in pgp text!"
+	Exmh_Debug "No pattern matches version info in pgp text!"
+	Exmh_Debug "Falling back to $pgp(noversion)"
+	set bestversion $pgp(noversion)
     }
 
     # look, if the version is setup
