@@ -236,6 +236,11 @@ proc SeditMimeFirstPart { t type promote keep} {
 	SeditMsg $t "No message?"
 	$t mark set header end
     }
+    if [$t compare header == "header linestart"] {
+	# last header line was deleted during editing -- back up
+	# over newline
+	$t mark set header "header - 1c"
+    }
     $t insert header "\nMime-Version: 1.0"
     if [$t compare header == "end -1c"] {
 	# Nothing left after deleting the body
@@ -359,7 +364,18 @@ proc SeditStartMulti {t type {empty {}} } {
     $t mark set start $h
 
     if {$sedit($t,dash)} {
-	set dash "start lineend + 1c"
+	
+	# We need to find the dash.  Rather than assume that it has
+	# a particular relation to the start index, it's probably
+	# safer to just scan for it, since the user could either
+	# 1) Delete the Content-Type: header that usually precedes
+	# the dash or 2) Insert something else before the dash.
+	# Things could be bad for us if they actually deleted the dash.
+	set dash start
+	while {[$t get $dash "$dash + 1c"] != "-"} {
+	    set dash "$dash lineend + 1c"
+	}
+
 	# Insert copy of dashed line into outer body
 	$t insert start [$t get $dash "$dash lineend"]
 	# Remove dashed line from inner body, replacing it with blank line
